@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP #-}
+{-# OPTIONS_GHC -fno-warn-warnings-deprecations #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Network
@@ -431,10 +432,10 @@ bracketOnError = Exception.bracketOnError
 
 {-$buffering
 
-The 'Handle' returned by 'connectTo' and 'accept' is block-buffered by
+The 'Handle' returned by 'connectTo' and 'accept' is 'NoBuffering' by
 default.  For an interactive application you may want to set the
 buffering mode on the 'Handle' to
-'LineBuffering' or 'NoBuffering', like so:
+'LineBuffering' or 'BlockBuffering', like so:
 
 > h <- connectTo host port
 > hSetBuffering h LineBuffering
